<?php

require_once('Author_Model.php');

class FGPAuthor{
    
    public $admin_option_name;

    public $is_registered_author;

    public $fgpauthor_model;

    public function __construct($api_key){

        $this->fgpauthor_model = new FGPAuthorModel();
                
        $this->fgpauthor_model->setApiKey($api_key);

        $this->admin_option_name = 'fgp_author_options';

        $fgp_author_options = maybe_unserialize(get_option($this->admin_option_name));

        if($fgp_author_options === false){

            $fgp_author_options = array('author_id'=> '', 'publisher_id'=> '');

            add_option($this->admin_option_name, maybe_serialize($fgp_author_options));

        }

        if(isset($fgp_author_options['author_id']) && !empty($fgp_author_options['author_id'])){

            $this->is_registered_author = true;

            $this->fgpauthor_model->setAuthorId($fgp_author_options['author_id']);

        }



    }

    public function run(){

        add_action('admin_menu', array(&$this, 'initAdminMenu'));
        
    }

    public function initAdminMenu() {

        //main menu setup
        add_menu_page('FGP Author', 'FGP Author', 'manage_options', 'fgp-author', array(&$this, 'viewFgpDashboard'), null, '100.1');

        //submenu setups
        add_submenu_page( 'fgp-author', 'My Articles', 'My Articles', 'manage_options', 'fgp-author-my-articles', array(&$this, 'viewMyArticles'));
        add_submenu_page( 'fgp-author', 'Article Approval', 'Article Approval', 'manage_options', 'fgp-author-article-approval', array(&$this, 'viewArticleForApproval'));
        add_submenu_page( 'fgp-author', 'Content Requests', 'Content Requests', 'manage_options', 'fgp-author-content-requests', array(&$this, 'viewContentRequests'));
        add_submenu_page( 'fgp-author', 'Requested Changes', 'Requested Changes', 'manage_options', 'fgp-author-requested-changes', array(&$this, 'viewRequestedChanges'));

        //invisible subpages
        add_submenu_page( null, 'FGP Author Registration Page' , 'FGP Author Registration Page', 'manage_options', 'fgp-author-register', array(&$this, 'authorRegistrationForm'));
        add_submenu_page( null, 'FGP Author Edit Article Page' , 'FGP Author Edit Article Page', 'manage_options', 'fgp-author-edit-article', array(&$this, 'editArticlePage'));
        add_submenu_page( null, 'FGP Author Delete Article Page' , 'FGP Author Delete Article Page', 'manage_options', 'fgp-author-delete-article', array(&$this, 'deleteArticlePage'));
        add_submenu_page( null, 'FGP Author Article Approval Form' , 'FGP Author Article Approval Form', 'manage_options', 'fgp-author-article-approval-process', array(&$this, 'articleApprovalProcess'));
        add_submenu_page( null, 'FGP Author Content Request Processing' , 'FGP Author Content Request Processing', 'manage_options', 'fgp-author-content-requests-process', array(&$this, 'contentRequestProcess'));

    }
    
    public function editArticlePage(){

        if(!$this->is_registered_author){
            echo '<script>location.href="admin.php?page=fgp-author-register";</script>';
        }

        if(empty($_GET['article_id'])){
            echo '<script>location.href="admin.php?page=fgp-author-my-articles";</script>';
        }

        if(isset($_POST['submit_edit_article'])){

            array_pop($_POST);

            $this->fgpauthor_model->saveEditArticle($_POST, $_GET['article_id']);

            echo '<script>location.href="admin.php?page=fgp-author-my-articles";</script>';
        }

        $api_categories = $this->fgpauthor_model->getApiCategories();

        $request = $this->fgpauthor_model->getArticle($_GET['article_id']);

        $article = $request->data->article;

        include_once($this->plugin_path . 'views/author/edit_article.php');
        
    }


    public function deleteArticlePage(){

        if(!$this->is_registered_author){
            echo '<script>location.href="admin.php?page=fgp-author-register";</script>';
        }

        if(!empty($_GET['article_id'])){

            $this->fgpauthor_model->deleteArticle($_GET['article_id']);

            echo '<script>location.href="admin.php?page=fgp-author-my-articles";</script>';
        }

    }

    public function viewFgpDashboard(){

        if(!$this->is_registered_author){
            echo '<script>location.href="admin.php?page=fgp-author-register";</script>';
        }

        
        
        include_once($this->plugin_path . 'views/author/dashboard.php');
        
    }

    public function viewMyArticles(){



        if(!$this->is_registered_author){
            echo '<script>location.href="admin.php?page=fgp-author-register";</script>';
        }
        
//        echo $this->fgpauthor_model->author_id;
        
        $request = $this->fgpauthor_model->loadMyArticlesViaApi();
        
        $my_articles = $request->data;
        
//        p($my_articles);
        
        include_once($this->plugin_path . 'views/author/my_articles.php');

    }

    public function authorRegistrationForm(){

        if($this->is_registered_author){
            echo '<script>location.href="admin.php?page=fgp-author";</script>';
        }

        if(isset($_POST['register_author'])){

            $request = $this->fgpauthor_model->registerNewAuthor($_POST);
            
            $fgp_author_options = maybe_unserialize(get_option($this->admin_option_name));
            
            $fgp_author_options['author_id'] = $request->author_id;
            
            $fgp_author_options['publisher_id'] = $request->publisher_id;
            
            update_option( $this->admin_option_name, $fgp_author_options );

            echo '<script>location.href="admin.php?page=fgp-author";</script>';
            
        }

        include_once($this->plugin_path . 'views/author/author_register.php');

    }

    public function viewArticleForApproval(){

        if(!$this->is_registered_author){
            echo '<script>location.href="admin.php?page=fgp-author-register";</script>';
        }

        $request = $this->fgpauthor_model->getArticlesForApproval();

        $articles_for_approval = $request->data;

        include_once($this->plugin_path . 'views/author/article_approval.php');        

    }

    public function articleApprovalProcess(){
        
        if(!$this->is_registered_author){
            echo '<script>location.href="admin.php?page=fgp-author-register";</script>';
        }

        if(empty($_GET['approval_id'])){
            echo '<script>location.href="admin.php?page=fgp-author-article-approval";</script>';
        }

        if(isset($_POST['submit_process_approval'])){

            $status =1; //1  == approved

            $this->fgpauthor_model->processArticleApproval($_POST['approval_id'], $status);

            echo '<script>location.href="admin.php?page=fgp-author-article-approval";</script>';

        }

        if(isset($_POST['submit_decline_approval'])){
            
            $status = 2; //2 == declined

            $this->fgpauthor_model->processArticleApproval($_POST['approval_id'], $status);

            echo '<script>location.href="admin.php?page=fgp-author-article-approval";</script>';

        }

        $request = $this->fgpauthor_model->getArticleForApproval($_GET['approval_id']);

        $article_for_approval = $request->data[0];

        include_once($this->plugin_path . 'views/author/article_approval_process.php');
        
    }

    public function viewContentRequests(){

        if(!$this->is_registered_author){
            echo '<script>location.href="admin.php?page=fgp-author-register";</script>';
        }

        $content_requests = $this->fgpauthor_model->getContentRequests();

//        p($content_requests);
        
        include_once($this->plugin_path . 'views/author/content_request.php');

    }


    public function contentRequestProcess(){

        if(!$this->is_registered_author){
            echo '<script>location.href="admin.php?page=fgp-author-register";</script>';
        }

        if(empty($_GET['arc_id'])){
            echo '<script>location.href="admin.php?page=fgp-author-content-requests";</script>';
        }

        if(isset($_POST['submit_process_content_request'])){

            $this->fgpauthor_model->processContentRequest($_POST, $_GET['arc_id']);

            echo '<script>location.href="admin.php?page=fgp-author-content-requests";</script>';

        }

        $request = $this->fgpauthor_model->getContentRequestById($_GET['arc_id']);

        $content_request = $request->data;

        include_once($this->plugin_path . 'views/author/content_request_process.php');
        
    }
    

    public function viewRequestedChanges(){

        if(!$this->is_registered_author){
            echo '<script>location.href="admin.php?page=fgp-author-register";</script>';
        }
        
        include_once($this->plugin_path . 'views/author/requested_changes.php');        

    }

    
    public function articleListingForm() {

        if(!$this->is_registered_author){
            echo '<script>location.href="admin.php?page=fgp-author-register";</script>';
        }

    }
	
}

$obj_fgpauthor = new FGPAuthor($this->api_key);
$obj_fgpauthor->run();