<?php
/*
Plugin Name: Free Guest Post
Plugin URI: http://www.freeguestpost.com
Description: That absolute easiest way for publishers to get original, relevant guest posts for their blogs
Version: 1.2.1
Author: Adam Sorensen | adams@fiber.net
 * 
 * @todos'  *implement nonce on all forms
 *          *add validations to forms 
 *          *add validations on publisher to check for username existence
 *          *add validations on publisher to check for email existence
*/

require_once('Model.php');

class eSourceGhostWriterPlugin{

    public $admin_option_name;

    public $admin_options;

    public $ghostwriter_model;

    public $plugin_path;

    public $plugin_url;
    
    public $api_key;
    
    public $importpost_cron;

    public function __construct(){

        $this->ghostwriter_model = new eSourceGhostWriterPluginModel();

        $this->admin_option_name = 'free_writer_plugin_options';

        $this->plugin_path = ABSPATH . 'wp-content/plugins/free-guest-post/';

        $this->plugin_url = plugins_url() . '/free-guest-post/';
        
        $free_writer_option = get_option($this->admin_option_name);
        
        if($free_writer_option === false){
            
            $free_writer_option = array('api_key'=> '');
            
            add_option($this->admin_option_name, maybe_serialize($free_writer_option));
            
        }
        
        $free_writer_option = maybe_unserialize($free_writer_option);

        $this->admin_options = $free_writer_option;
        
        $this->api_key = $free_writer_option['api_key'];
        
        $this->ghostwriter_model->setApiKey($this->api_key);
        
        $this->importpost_cron = getschedule('import_approved_post');

        if(isset($this->admin_options['enable_author'])){
            require_once 'author.php';
        }
        
        
        
    }

    public function run(){

        add_action('admin_menu', array(&$this, 'initAdminMenu'));
        
        register_activation_hook(__FILE__, array(&$this,'freeWriterActivate'));

        add_action('admin_init', array(&$this,'freeWriterRedirect'));

        add_action('init', array(&$this, 'loadImportFrame'));
        
        add_action('import_approved_post', array(&$this, 'ImportApprovedPostCron'));
        
        add_action('wp_trash_post', array(&$this,'updateArticleDelete'));
        
        add_action('before_delete_post', array(&$this,'updateArticleDelete'));  
         
    }

    public function loadImportFrame(){
        
        if($_GET['act'] == 'arc'){
            
            $request = $this->ghostwriter_model->getArticle($_GET['article_id']);

            $article = $request->data->article;
            
            $article_preview = $this->ghostwriter_model->api_url . '/articles/preview/'. $this->api_key . '/' .$_GET['article_id'] . '/arc_id/' . $_GET['arc_id'];
            
            $request = $this->ghostwriter_model->getRequestedChangesById($_GET['arc_id']);
            
            $requested_changes = $request->data->requested_changes;
            
            $categories = $this->ghostwriter_model->getCategories();            
            
            if(isset($_POST['import_post'])){

                //set title
                if($_POST['auto_import_title'] == 1){
                    $title = $article->title;
                }else{
                    $title = (!empty($_POST['new_title'])) ? $_POST['new_title'] : $article->title;
                }

                $tags = '';

                //set tags
                if(isset($_POST['auto_import_tags'])){

                    $tags = implode(', ', explode("\n", $article->tags));

                }

                if(!empty($_POST['additional_tags'])){
                    $tags = (!empty($tags)) ? $tags . ', ' . $_POST['additional_tags'] : $_POST['additional_tags'];
                }

                //set categories
                $categories = array();

                if(isset($_POST['categories'])){
                    $categories = $_POST['categories'];
                }

                $post_to_import = array(
                  'post_title'    => $title,
                  'post_content'  => $requested_changes->new_article_content,
                  'post_status'   => 'publish',
                  'post_author'   => wp_get_current_user()->ID,
                  'tags_input'   => $tags,
                  'post_category' => $categories
                );

                $post_id = wp_insert_post( $post_to_import );

                $this->ghostwriter_model->setArticleAsPublished($_GET['article_id'], $post_id);

                echo '<script>window.top.location.href = "admin.php?page=free-writer-published-articles";</script>';                
            }            
   
            include_once($this->plugin_path . 'views/article_request.php');
            die();
            
        }

        if($_GET['act']=='iframe') {

            $request = $this->ghostwriter_model->getArticle($_GET['article_id']);

            $article = $request->data->article;

            $article_preview = $this->ghostwriter_model->api_url . '/articles/preview/'. $this->api_key . '/' .$_GET['article_id'];
            
            $categories = $this->ghostwriter_model->getCategories();
            
            $id =  $_GET['id'];
            
            $type =  $_GET['type'];

            if(isset($_POST['import_post'])){

                //set title
                if($_POST['auto_import_title'] == 1){
                    $title = $article->title;
                }else{
                    $title = (!empty($_POST['new_title'])) ? $_POST['new_title'] : $article->title;
                }

                $tags = '';

                //set tags
                if(isset($_POST['auto_import_tags'])){

                    $tags = implode(', ', explode("\n", $article->tags));

                }

                if(!empty($_POST['additional_tags'])){
                    $tags = (!empty($tags)) ? $tags . ', ' . $_POST['additional_tags'] : $_POST['additional_tags'];
                }

                //set categories
                $categories = array();

                if(isset($_POST['categories'])){
                    $categories = $_POST['categories'];
                }
                
                if($article->bio){
                  $post_content =  $article->article . '<div class="authorbio">' .  $article->bio . '</div>';
                } else {
                  $post_content =  $article->article . '<div class="authorbio">' .  $article->default_bio . '</div>';                
                }
                
                
                $post_to_import = array(
                  'post_title'    => $title,
                  'post_content'  => $post_content,
                  'post_status'   => 'publish',
                  'post_author'   => wp_get_current_user()->ID,
                  'tags_input'   => $tags,
                  'post_category' => $categories
                );
                
                $post_id = wp_insert_post( $post_to_import );

                $this->ghostwriter_model->setArticleAsPublished($_GET['article_id'], $post_id);
                
                echo '<script>window.top.location.href = "admin.php?page=free-writer-published-articles";</script>';
                

            } else if(isset($_POST['decline_post'])){
       
              array_pop($_POST);
              
              $this->ghostwriter_model->setArticleAsDeclined($_POST);
             
              if($_GET['redirect']) {                 
                echo '<script>window.top.location.href="admin.php?page='. $_GET['redirect'].'";</script>'; 
              }
              
              echo '<script>window.top.location.href="admin.php?page=free-writer";</script>';    
            }
            
            if(isset($_POST['request_changes'])){
             
                if(isset($_POST['request_changes_process'])){
                    
                    unset($_POST['request_changes_process'], $_POST['request_changes']);
                    
                    $this->ghostwriter_model->processRequestChanges($_POST);
                    
                    echo '<script>window.top.location.href = "admin.php?page=free-writer";</script>';                    
                    
                }
                        
                include_once($this->plugin_path . 'views/request_changeform.php');
                die();
                        
            }

            unset($request);

            include_once($this->plugin_path . 'views/blank.php');
            die();
        }
        
        if($_GET['act']=='iframeforapproval') {

            $request = $this->ghostwriter_model->getArticle($_GET['article_id']);

            $article = $request->data->article;

            $article_preview = $this->ghostwriter_model->api_url . '/articles/preview/'. $this->api_key . '/' .$_GET['article_id'];
            
              
            if(isset($_POST['request_approval'])){
       
              array_pop($_POST);
              
              $this->ghostwriter_model->sendApprovalRequest($_POST);
              if($_GET['redirect']) {                 
                echo '<script>window.top.location.href="admin.php?page='. $_GET['redirect'].'";</script>'; 
              }
              
              echo '<script>window.top.location.href="admin.php?page=free-writer";</script>';    
            }
            include_once($this->plugin_path . 'views/approval_blank.php');
            
            die();
         }
         
         if($_GET['act']=='iframeeditrequest') {

            $request = $this->ghostwriter_model->getContentRequestById($_GET['id']);
            
            $content_request = $request->data;
            
            $api_categories = $this->ghostwriter_model->getApiCategories(); 
            
            if(isset($_POST['request_content'])){
       
              array_pop($_POST);
              
              $this->ghostwriter_model->processContentRequest($_POST, $_GET['id']);
            
              if($_GET['redirect']) {                 
                echo '<script>window.top.location.href="admin.php?page='. $_GET['redirect'].'";</script>'; 
              }
              
              echo '<script>window.top.location.href="admin.php?page=free-writer";</script>';    
            }
            include_once($this->plugin_path . 'views/content_request_blank.php');
            
            die();
         }

    }

    public function initAdminMenu() {

        //main menu setup
        add_menu_page('Free Guest Post Plugin', 'Free Guest Post', 'manage_options', 'free-writer', array(&$this, 'dashBoardForm'), null, '100');

        //submenu setups
        
        add_submenu_page( 'free-writer', 'Dashboard', 'Dashboard', 'manage_options', 'free-writer', array(&$this, 'dashBoardForm'));       
        add_submenu_page( 'free-writer', 'Available Articles', 'Available Articles', 'manage_options', 'free-writer-articles-list', array(&$this, 'articleListingForm'));       
        add_submenu_page( 'free-writer', 'Published Articles', 'Published Articles', 'manage_options', 'free-writer-published-articles', array(&$this, 'viewPublishedArticles'));
        add_submenu_page( 'free-writer', 'Request Articles', 'Request Articles', 'manage_options', 'free-writer-request-post', array(&$this, 'requestPostForm'));
        add_submenu_page( 'free-writer', 'Feedback', 'Feedback', 'manage_options', 'free-writer-feedback', array(&$this, 'feedbackForm'));
        add_submenu_page( 'free-writer', 'Settings', 'Settings', 'manage_options', 'free-writer-setting', array(&$this, 'settingsForm'));
        add_submenu_page( null, 'Free Writer Registration Page' , 'Free Writer Registration Page', 'manage_options', 'free-writer-register', array(&$this, 'registrationForm'));
        add_submenu_page( null, 'Free Writer Search Results Page' , 'Free Writer Search Results Page', 'manage_options', 'free-writer-search', array(&$this, 'viewSearchResults'));
        add_submenu_page( null, 'Articles to Import' , 'Articles to Import', 'manage_options', 'free-writer-articles-to-import', array(&$this, 'articlestoImportForm'));
        add_submenu_page( null, 'Available Articles' , 'Available Articles', 'manage_options', 'free-writer-articles-available', array(&$this, 'availableArticlesForm'));
       
     }

    public function viewPublishedArticles(){
        
        if(empty($this->api_key)){
            echo '<script>location.href="admin.php?page=free-writer-register";</script>';
        }

        $articles = $this->ghostwriter_model->getPublishedArticles();

        $published_articles = array();

        foreach($articles as $key => $value){

            $value->view_link = get_permalink($value->wp_post_id);
            $value->edit_link = get_edit_post_link($value->wp_post_id);

            $published_articles[] = $value;

        }

        unset($articles);

        include_once($this->plugin_path . 'views/published_articles.php');

    }

    public function viewSearchResults(){
        
        if(empty($this->api_key)){
            echo '<script>location.href="admin.php?page=free-writer-register";</script>';
        }
        
        if(empty($_POST)){
            echo '<script>location.href="admin.php?page=free-writer-register";</script>';
        }
        
        $response = $this->ghostwriter_model->searchArticle($_POST);
        
        $search_criteria = $response->data->search_criteria;
        
        if($search_criteria->search_by == 'category'){
            $api_categories = $this->ghostwriter_model->getApiCategories(); 
            $search_criteria->keyword = $api_categories[$search_criteria->category];
        }
        
        $articles = $response->data->articles;
              
        include_once($this->plugin_path . 'views/search_results.php');

    }
    
    public function registrationForm(){
        
        if(!empty($this->api_key)){
            echo '<script>location.href="admin.php?page=free-writer";</script>';
        }
        
        if(isset($_POST['submit_registration'])){
            
            $request = $this->ghostwriter_model->registerNewPublisher($_POST);
            
            $free_writer_option = maybe_unserialize(get_option($this->admin_option_name));
            
            $free_writer_option['api_key'] = $request->data->api_key;
            
            update_option( $this->admin_option_name, $free_writer_option );
            
            echo '<script>location.href="admin.php?page=free-writer";</script>';
            
        }
        
        if(isset($_POST['submit_apikey'])){
            
            $request = $this->ghostwriter_model->validateApiKey($_POST['api_key']);        
            
            if($request->status == 'success'){
                
                $free_writer_option = maybe_unserialize(get_option($this->admin_option_name));

                $free_writer_option['api_key'] = $_POST['api_key'];

                update_option( $this->admin_option_name, $free_writer_option );

                echo '<script>location.href="admin.php?page=free-writer";</script>';
                
            }else{
                $error_message = $request->data->api_key;
            }
            
        }
        
        include_once($this->plugin_path . 'views/register.php');
        
    }
    
    public function articleListingForm() {
        
        if(empty($this->api_key)){
            echo '<script>location.href="admin.php?page=free-writer-register";</script>';
        }
        
        
        if(isset($_POST['request_approval'])){
       
            array_pop($_POST);
            
            $this->ghostwriter_model->sendApprovalRequest($_POST);
          
            echo '<script>location.href="admin.php?page=free-writer";</script>';            
            
        }  
        
        
        
        $categories = $this->ghostwriter_model->getCategories();        

        $api_categories = $this->ghostwriter_model->getApiCategories();
                
        $articles = $this->ghostwriter_model->parse('articles/load/');            
       
        include_once($this->plugin_path . 'views/article_list.php');

    }
	
    public function settingsForm() {

//        p($this->admin_options);
        
        if(empty($this->api_key)){
            echo '<script>location.href="admin.php?page=free-writer-register";</script>';
        }
        
        $email_notificationr = $this->ghostwriter_model->getPublisherEmailNotification(); 
       
        $email_notification = $email_notificationr[0]->email_notification;    
       
        if(isset($_POST['save_settings'])){

            array_pop($_POST);                                
            
            if(!isset($_POST['enable_email_notification'])) {
               $enable_email_notification = 0;
            } else {
               $enable_email_notification = 1;
            }
            
            $this->ghostwriter_model->savePublisherEmailNotification($enable_email_notification); 
            
            $this->ghostwriter_model->savePublisherSettings(maybe_serialize($_POST)); 
            
            update_option($this->admin_option_name, maybe_serialize($_POST));

            echo '<script>location.href="admin.php?page=free-writer-setting";</script>';

        }
         
                     
        if($_POST['importcron']) {
        
           if ( !wp_next_scheduled( 'import_approved_post' ) ) {
               wp_schedule_event( time(), $_POST['importcron'], 'import_approved_post');
	         }
        } else {
           wp_clear_scheduled_hook('import_approved_post');
        }
        
        $schedules = wp_get_schedules();
        
        $api_categories = $this->ghostwriter_model->getApiCategories(); 

        include_once($this->plugin_path . 'views/settings.php');

    }


    public function requestPostForm() {
        
        if(empty($this->api_key)){
            echo '<script>location.href="admin.php?page=free-writer-register";</script>';
        }
        
        $content_requests = $this->ghostwriter_model->getContentRequests();
        
        /**
         * 
         * Temporarily Commented
        $articles = $this->ghostwriter_model->parse('articles/load/');
       
        $article_titles = array();
        if($articles) {
          foreach($articles as $article) {
              $article_titles_r[] =  $article->title;
          }
          
          if (count($article_titles_r) > 0){
               $article_titles = implode('","' , $article_titles_r);
          }
        }
        
         * **/
        
        if(isset($_POST['request_content'])){
            
            array_pop($_POST);
            
            $this->ghostwriter_model->addNewContentRequest($_POST);
            
            echo '<script>location.href="admin.php?page=free-writer-request-post";</script>';            
            
        }
        
        if(isset($_POST['deletecontentrequest'])){
            
            array_pop($_POST);
            
            $this->ghostwriter_model->deleteContentRequest($_POST);
            
            echo '<script>location.href="admin.php?page=free-writer-request-post";</script>';            
            
        }
        
        
//        p($_POST);
         
        $api_categories = $this->ghostwriter_model->getApiCategories();
        
        include_once($this->plugin_path . 'views/request_post.php');

    }
    
    
    public function freeWriterActivate() {
        
        add_option('free_writer_activate_redirect', true);
        
    }

    public function freeWriterRedirect() {
        
        if (get_option('free_writer_activate_redirect', false)) {
            
            delete_option('free_writer_activate_redirect');
            
            wp_redirect('admin.php?page=free-writer-setting');
            
        }
    }  
    
    public function ImportApprovedPostCron() {
       $articlesapproved = $this->ghostwriter_model->parse('articles/approved/');
       if(count($articlesapproved)) {
          foreach ($articlesapproved as $article) {
            
            $tags = implode(', ', explode("\n", $article->tags));
        
            //set categories
            $categories = array();
                  
            $post_to_import = array(
                    'post_title'    => $article->title,
                    'post_content'  => $article->article,
                    'post_status'   => 'publish',
                    'post_author'   => $article->publisher_id,
                    'tags_input'   => $tags,
                    'post_category' => $categories
                  );
  
              $post_id = wp_insert_post( $post_to_import );
      
              $this->ghostwriter_model->setArticleAsPublished($article->id, $post_id);  
          }
       }
                
    }   
    
    public function dashBoardForm() {
        
        if(empty($this->api_key)){
            echo '<script>location.href="admin.php?page=free-writer-register";</script>';
        }
        
        if(isset($_POST['request_approval'])){
       
            array_pop($_POST);
            
            $this->ghostwriter_model->sendApprovalRequest($_POST);
          
            echo '<script>location.href="admin.php?page=free-writer";</script>';            
            
        }    
        
        if(isset($_POST['deletecontentrequest'])){
            
            array_pop($_POST);
            
            $this->ghostwriter_model->deleteContentRequest($_POST);
            
            echo '<script>location.href="admin.php?page=free-writer";</script>';            
            
        }
         
        $categories = $this->ghostwriter_model->getCategories();        

        $api_categories = $this->ghostwriter_model->getApiCategories();
                
        $articles = $this->ghostwriter_model->parse('articles/toimport/');
        
        $available_articles = $this->ghostwriter_model->parse('articles/availablearticles/');                
        
        $content_requests = $this->ghostwriter_model->getContentRequests();
        
        include_once($this->plugin_path . 'views/dashboard.php');

    }
    
    public function articlestoImportForm() {
        
        if(empty($this->api_key)){
            echo '<script>location.href="admin.php?page=free-writer-register";</script>';
        }
        
                
        $articles = $this->ghostwriter_model->parse('articles/toimport/');
        
        include_once($this->plugin_path . 'views/articles_to_import.php');

    }
    
    public function availableArticlesForm() {
        
        if(empty($this->api_key)){
            echo '<script>location.href="admin.php?page=free-writer-register";</script>';
        }  
                
        if(isset($_POST['request_approval'])){
       
            array_pop($_POST);
            
            $this->ghostwriter_model->sendApprovalRequest($_POST);
          
            echo '<script>location.href="admin.php?page=free-writer-articles-available";</script>';            
            
        }  
        
                
        $available_articles = $this->ghostwriter_model->parse('articles/availablearticles/');
        
        include_once($this->plugin_path . 'views/articles_available.php');

    }
    
    
    function updateArticleDelete($post_id){
      $this->ghostwriter_model->setPublishedArticleAsDeleted($post_id);
    }
    
    public function feedbackForm() {
        
        if(empty($this->api_key)){
            echo '<script>location.href="admin.php?page=free-writer-register";</script>';
        }  
                
        if(isset($_POST['submit_feedback'])){
       
            array_pop($_POST);
            
            $error=false;
            $error_message='';
            if(empty($_POST['name'])){
              $error_messager[] = 'The Name field is required.';
              $error=true;
            }
            
            if(empty($_POST['email'])){     
              $error_messager[] = 'The Email field is required.';
              $error=true;
            } else if(!is_email($_POST['email'])) {
              $error_messager[] = 'The Email field must contain a valid email address.';
              $error=true;             
            }
            
            if(empty($_POST['comments'])){
              $error_messager[] = 'The Comments field is required.';
              $error=true;
            }
            
            if($error) {
               $error_message =  implode("<br/>", $error_messager);
            } else {
            
            $this->ghostwriter_model->sendFeedback($_POST);
          
            echo '<script>location.href="admin.php?page=free-writer-feedback&success=true";</script>';            
            
            }
        }  
        
                
        include_once($this->plugin_path . 'views/feedback.php');

    }
    
    
    
    
    
	
}   


//run plugin
$ghost_writer_obj = new eSourceGhostWriterPlugin();
$ghost_writer_obj->run();












/* misc functions || for debug purposes */
function p($arr){
    echo '<pre>';
    print_r($arr);
    echo '</pre>';
}

function htmlOptions($array, $selected){

    $retVal = '';

    if(is_array($selected)){

        foreach($array as $value => $label){
            
            $_selected = (in_array($value, $selected)) ? 'selected="selected"' : '';
            $retVal .= '<option value="'. $value .'" '. $_selected .'> ' . $label . '</option>';
        }


    }else{

        foreach($array as $value => $label){
            $_selected = ($selected == $value) ? 'selected="selected"' : '';
            $retVal .= '<option value="'. $value .'" '. $_selected .'> ' . $label . '</option>';
        }

    }

    return $retVal;

}

function getschedule($name) {
  $cron = _get_cron_array();
  //print_r($cron);
  foreach ($cron as $time ) {
    if ( array_key_exists($name, $time)) {
      foreach($time as $schedulek => $scheduler) {
        foreach($scheduler as $schedule) {
          return $schedule['schedule'];                            
        }
      }
    }
  } 
  
  return 0;  
  
}
